
# Type: types


data types used in the model

URI: [meta:types](https://w3id.org/biolink/biolinkml/meta/types)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>0..*</sub> [TypeDefinition](TypeDefinition.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
